# NNNN — Title of Decision

## Status

Proposed | Accepted | Deprecated | Superseded by [NNNN](NNNN-title.md)

## Context

<!-- What is the issue motivating this decision? -->

## Decision

<!-- What is the change being proposed? -->

## Consequences

<!-- What are the positive and negative consequences of this decision? -->
